# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mutapath']

package_data = \
{'': ['*']}

install_requires = \
['cached-property==1.5.1',
 'filelock==3.0.12',
 'path.py==12.4.0',
 'singletons==0.2.3']

setup_kwargs = {
    'name': 'mutapath',
    'version': '0.15.5',
    'description': 'mutable pathlib',
    'long_description': '# mutapath\n\n[![Actions Status](https://github.com/matfax/mutapath/workflows/build/badge.svg)](https://github.com/matfax/mutapath/actions)\n[![codecov](https://codecov.io/gh/matfax/mutapath/branch/master/graph/badge.svg)](https://codecov.io/gh/matfax/mutapath)\n[![Renovate Status](https://badges.renovateapi.com/github/matfax/mutapath)](https://renovatebot.com/)\n[![CodeFactor](https://www.codefactor.io/repository/github/matfax/mutapath/badge)](https://www.codefactor.io/repository/github/matfax/mutapath)\n[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mutapath)](https://pypi.org/project/mutapath/)\n[![PyPI](https://img.shields.io/pypi/v/mutapath?color=%2339A7A6)](https://pypi.org/project/mutapath/)\n[![PyPI - Downloads](https://img.shields.io/pypi/dm/mutapath?color=%231447F9)](https://pypistats.org/packages/mutapath)\n[![Documentation Status](https://readthedocs.org/projects/mutapath/badge/?version=latest)](https://mutapath.readthedocs.io/en/latest/?badge=latest)\n[![GitHub License](https://img.shields.io/github/license/matfax/mutapath.svg)](https://github.com/matfax/mutapath/blob/master/LICENSE)\n[![GitHub last commit](https://img.shields.io/github/last-commit/matfax/mutapath?color=%232954A5)](https://github.com/matfax/mutapath/commits/master)\n\n\nThis library is for you if you are also annoyed that there is no mutable pathlib wrapper for use cases where paths are often changed.\nmutapath solves this by wrapping the extended pathlib library [path.py](https://pypi.org/project/path.py/) and updating the encapsulated object every time the path might be changed.\n\nmutapath also adds the possibility to delimit file and path modifications to a safe fallback context.\n\n## MutaPath Class\n\nThe MutaPath Class allows direct manipulation of its attributes at any time, just as any mutable object.\nOnce a file operation is called that is intended to modify its path, the underlying path is also mutated.\n\n```python\n>>> from mutapath import MutaPath\n```\n```python\n>>> folder = MutaPath("/home/joe/doe/folder/sub")\n>>> folder\nPath(\'/home/joe/doe/folder/sub\')\n```\n```python\n>>> folder.name = "top"\n>>> folder\nPath(\'/home/joe/doe/folder/top\')\n```\n```python\n>>> next = MutaPath("/home/joe/doe/folder/next")\n>>> next\nPath(\'/home/joe/doe/folder/next\')\n```\n```python\n>>> next.rename(folder)\n>>> next\nPath(\'/home/joe/doe/folder/top\')\n>>> next.exists()\nTrue\n>>> Path(\'/home/joe/doe/folder/sub\').exists()\nFalse\n```\n\n## Path Class\n\nThis class is immutable by default, just as the `pathlib.Path`. However, it allows to open a editing context via `mutate()`.\nMoreover, there are additional contexts for file operations. They update the file and its path while closing the context.\nIf the file operations don\'t succeed, they throw an exception and fall back to the original path value.\n\n```python\n>>> from mutapath import Path\n```\n```python\n>>> folder = Path("/home/joe/doe/folder/sub")\n>>> folder\nPath(\'/home/joe/doe/folder/sub\')\n```\n```python\n>>> folder.name = "top"\nAttributeError: mutapath.Path is an immutable class, unless mutate() context is used.\n>>> folder\nPath(\'/home/joe/doe/folder/sub\')\n```\n```python\n>>> with folder.mutate() as m:\n...     m.name = "top"\n>>> folder\nPath(\'/home/joe/doe/folder/top\')\n```\n```python\n>>> next = Path("/home/joe/doe/folder/next")\n>>> next.copy(folder)\n>>> next\nPath(\'/home/joe/doe/folder/next\')\n>>> folder.exists()\nTrue\n>>> folder.remove()\n```\n```python\n>>> with next.renaming() as m:\n...     m.stem = folder.stem\n...     m.suffix = ".txt"\n>>> next\nPath("/home/joe/doe/folder/sub.txt")\n>>> next.exists()\nTrue\n>>> next.with_name("next").exists()\nFalse\n```\n\n\nFor more in-depth examples, check the tests folder.\n\n## Hashing\n\nmutapath paths are hashable by caching the generated hash the first time it is accessed.\nHowever, it also adds a warning so that unintended hash usage is avoided.\nOnce mutated after that, the generated hashes don\'t provide collision detection in binary trees anymore.\nDon\'t use them in sets or as keys in dicts.\nUse the explicit string representation instead, to make the hashing input transparent.\n\n```python\n>>> p = Path("/home")\n>>> hash(p)\n1083235232\n>>> hash(Path("/home")) == hash(p)\nTrue\n>>> with p.mutate() as m:\n...     m.name = "home4"\n>>> hash(p) # same hash\n1083235232\n>>> hash(Path("/home")) == hash(p) # they are not equal anymore\nTrue\n```\n',
    'author': 'matfax',
    'author_email': 'matthias.fax@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/matfax/mutapath',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
